<?php

namespace App\Http\Livewire;

use App\Models\Proveedores as ModelsProveedores;
use App\Models\Tipos_Proveedores;
use Livewire\Component;

class Proveedores extends Component
{
    public $data, $tipos, $clave_interna, $nombre_negocio, $direccion, $telefono, $email, $tipo_proveedor_id, $selected_id, $rfc;
    public $updateMode = false;

    public function render()
    {
        $this->tipos = Tipos_Proveedores::all();
        $this->data = ModelsProveedores::with('tipos')->get();
        return view('livewire.Proveedores.proveedores');
    }

    private function resetInput()
    {
        $this->clave_interna = null;
        $this->nombre_negocio = null;
        $this->direccion = null;
        $this->telefono = null;
        $this->email = null;
        $this->tipo_proveedor_id = null;
        $this->rfc = null;
    }

    public function store()
    {
        $this->validate([
            'clave_interna' => 'required|min:2',
            'nombre_negocio' => 'required|min:2',
            'direccion' => 'required|min:2',
            'telefono' => 'required|min:2',
            'email' => 'required|min:2',
            'tipo_proveedor_id' => ''
        ]);
        ModelsProveedores::create([
            'clave_interna' => $this->clave_interna,
            'nombre_negocio' => $this->nombre_negocio,
            'direccion' => $this->direccion,
            'telefono' => $this->telefono,
            'email' => $this->email,
            'tipo_proveedor_id' => $this->tipo_proveedor_id
        ]);

        $this->resetInput();
    }

    public function edit($id)
    {
        $record = ModelsProveedores::findOrFail($id);

        $this->selected_id = $id;
        $this->clave_interna = $record->clave_interna;
        $this->nombre_negocio = $record->nombre_negocio;
        $this->direccion = $record->direccion;
        $this->telefono = $record->telefono;
        $this->email = $record->email;
        $this->tipo_proveedor_id = $record->tipo_proveedor_id;
        $this->rfc = $record->rfc;

        $this->updateMode = true;

    }

    public function update()
    {
        $this->validate([
            'selected_id' => 'required|numeric'
        ]);

        if ($this->selected_id)
        {
            $record = ModelsProveedores::find($this->selected_id);
            $record->update([
                'clave_interna' => $this->clave_interna,
                'nombre_negocio' => $this->nombre_negocio,
                'direccion' => $this->direccion,
                'telefono' => $this->telefono,
                'email' => $this->email,
                'tipo_proveedor_id' => $this->tipo_proveedor_id,
                'rfc' => $this->rfc
            ]);

            $this->resetInput();
            $this->updateMode = false;
        }
    }

    public function destroy($id)
    {
        if ($id) {
            $record = ModelsProveedores::where('id', $id);
            $record->delete();
        }
    }
}
