<?php

namespace App\Http\Livewire;

use Livewire\Component;
use App\Models\Productos;
use App\Models\Proveedores;
use App\Models\Compras as Comprar;
use App\Models\DetalleCompras;
use Illuminate\Support\Facades\DB;
use Livewire\WithPagination;

class Compras extends Component
{
    use WithPagination;

    public $searchTerm;
    public $productos, $proveedores, $proveedor_id, $tipo_compra, $cantidad, $precio_compra, $selected_id, $data, $comprasAgrupadas, $costo_compra_editado, $costo_compra, $nombreProveedor;
    public $updateMode = false;
    public $create = false;
    public $principal = true;
    public $iniciar = false;
    public $arrayInicial = [];
    public $openModal = false;

    public function render()
    {
        $consulta = DB::table('compras')
        ->join('proveedores', 'compras.proveedor_id', '=', 'proveedores.id')
        ->select('compras.id', 'compras.tipo_compra', 'compras.descripcion', 'compras.total', 'compras.created_at','proveedores.nombre_negocio',)->get();
        $this->data = $consulta;
        if ($this->create) {
            return view('livewire.Compras.create');
        }elseif ($this->iniciar) {
            return view('livewire.Compras.iniciar');
        } else {
            return view('livewire.Compras.compras');
        }
    }

    private function resetInput()
    {
        $this->cantidad = null;
    }


    public function DetalleCompras($id)
    {
        $id = 1;
        $this->data = DB::table('compras')
        ->join('detalle_compras', 'compras.id', '=', 'detalle_compras.compra_id')
        ->join('productos', 'detalle_compras.producto_id', '=', 'productos.id')
        ->select('compras.id as Id Compra', 'productos.descripcion_producto as producto',
        'detalle_compras.cantidad', 'detalle_compras.precio_unitario as precioPieza')
        ->where('detalle_compras.compra_id', '=', $id)
        ->get();
    }

    public function iniciarCompra()
    {
        $this->iniciar = true;
        $this->proveedores = Proveedores::select('id', 'nombre_negocio')->get();
        $this->render();
    }

    public function create()
    {
        $this->openModal = true;
        $auxProveedor = Proveedores::find($this->proveedor_id);
        $this->nombreProveedor = $auxProveedor->nombre_negocio;
        $busqueda = $this->searchTerm
        ? Productos::where('descripcion_producto', 'LIKE', '%'.$this->searchTerm.'%')->get()
        : Productos::orderBy('descripcion_producto', 'desc')->limit(3)->get();
        $this->productos = $busqueda;

    }

    public function search()
    {
        $this->create = true;
        $this->render();
    }

    public function agregarProducto($id)
    {
        $prod = array();
        $this->validate([
            'cantidad' => 'required',
        ]);
        $record = Productos::findOrFail($id);

        if ($this->costo_compra_editado) {
            $costo_final = $this->costo_compra_editado;
        } else {
            $costo_final = $record->costo_compra;
        }
        $total = $this->cantidad * $costo_final;
        $prod = ([
            'id' => $record->id,
            'cantidad' => $this->cantidad,
            'costo_unitario' => $costo_final,
            'total_movimiento' => $total
        ]);
        array_push($this->arrayInicial, $prod);
        $this->resetInput();
        $this->render();
    }

    public function eliminar($index)
    {
        unset($this->arrayInicial[$index]);
        $this->render();
    }


}
