<?php

namespace App\Http\Livewire;

use Livewire\Component;
use App\Models\Gastos;
use App\Models\TipoGasto;

class Gasto extends Component
{
    public $data, $tipos, $descripcion, $costo, $tipos_gastos_id, $selected_id;
    public $updateMode = false;
    public $crear = false;

    public function render()
    {
        $this->tipos = TipoGasto::all();
        $this->data = Gastos::with('tiposg')->get();
        return view('livewire.Gasto.gasto');
    }

    private function resetInput()
    {
        $this->descripcion = null;
    }

    public function store()
    {
        $this->validate([
            'descripcion' => 'required'
        ]);
        Gastos::create([
            'descripcion' => $this->descripcion,
            'costo' => $this->costo,
            'tipos_gastos_id' => $this->tipos_gastos_id,
        ]);
        $this->crear = false;
        $this->resetInput();
    }

    public function edit($id)
    {
        $record = Gastos::findOrFail($id);

        $this->selected_id = $id;
        $this->descripcion = $record->descripcion;
        $this->costo = $record->costo;
        $this->tipos_gastos_id = $record->tipos_gastos_id;
        $this->updateMode = true;

    }

    public function update()
    {
        $this->validate([
            'selected_id' => 'required|numeric',
            'descripcion' => 'required|min:2'
        ]);

        if ($this->selected_id)
        {
            $record = Gastos::find($this->selected_id);
            $record->update([
                'descripcion' => $this->descripcion,
                'costo' => $this->costo,
            ]);

            $this->resetInput();
            $this->updateMode = false;
        }
    }

    public function destroy($id)
    {
        if ($id) {
            $record = Gastos::where('id', $id);
            $record->delete();
        }
    }
}
