<?php

namespace App\Http\Livewire;

use Livewire\Component;
use App\Models\Vendedores;

class Presales extends Component
{
    public $data, $titulos, $descripcion, $clave_interna, $nombre, $estado, $ciudad, $rfc, $direccion, $email, $telefono, $titulo_id, $selected_id;
    public $updateMode = false;

    public function render()
    {
        $this->data = Vendedores::all();
        return view('livewire.Presales.presales');
    }

    private function resetInput()
    {
        $this->descripcion = null;
        $this->clave_interna = null;
        $this->nombre = null;
        $this->estado = null;
        $this->ciudad = null;
        $this->rfc = null;
        $this->direccion = null;
        $this->email = null;
        $this->telefono = null;
    }

    public function store()
    {
        $this->validate([
            'clave_interna' => 'required|min:2',
            'nombre' => 'required|min:2'
        ]);
        Vendedores::create([
            'clave_interna' => $this->clave_interna,
            'nombre' => $this->nombre,
            'rfc' => $this->rfc,
            'direccion' => $this->direccion,
            'estado' => $this->estado,
            'ciudad' => $this->ciudad,
            'email' => $this->email,
            'telefono' => $this->telefono,
        ]);

        $this->resetInput();
    }

    public function edit($id)
    {
        $record = Vendedores::findOrFail($id);

        $this->selected_id = $id;
        $this->clave_interna = $record->clave_interna;
        $this->nombre = $record->nombre;
        $this->rfc = $record->rfc;
        $this->direccion = $record->direccion;
        $this->estado = $record->estado;
        $this->ciudad = $record->ciudad;
        $this->email = $record->email;
        $this->telefono = $record->telefono;

        $this->updateMode = true;

    }

    public function update()
    {
        $this->validate([
            'selected_id' => 'required|numeric'
        ]);

        if ($this->selected_id)
        {
            $record = Vendedores::find($this->selected_id);
            $record->update([
            'clave_interna' => $this->clave_interna,
            'nombre' => $this->nombre,
            'rfc' => $this->rfc,
            'direccion' => $this->direccion,
            'estado' => $this->estado,
            'ciudad' => $this->ciudad,
            'email' => $this->email,
            'telefono' => $this->telefono,
            ]);

            $this->resetInput();
            $this->updateMode = false;
        }
    }

    public function destroy($id)
    {
        if ($id) {
            $record = Vendedores::where('id', $id);
            $record->delete();
        }
    }
}
