<?php

namespace App\Http\Livewire;

use Livewire\Component;
use App\Models\Productos as Producto;
use App\Models\CategoriaProducto;
use App\Models\TipoMovimientoStock;
use Livewire\WithPagination;
use Illuminate\Pagination\Paginator;
use Illuminate\Support\Facades\DB;
use App\Models\MovimientosStock;

class Productos extends Component
{
    use WithPagination;

    public $search = '';
    public $categorias, $selected_id, $buscador, $clave_producto, $tipo_producto, $descripcion_producto, $categoria_producto_id, $marca_producto, $costo_compra, $precio_venta, $presentacion_producto, $stock_anterior, $stock_actual;
    public $updateMode = false;
    public $agregar = false;
    public $tipoMovimiento;
    public $tipo_movimiento_id;

    public function updatingSearch()
    {
        $this->resetPage();
    }

    public function render()
    {
        $this->tipoMovimiento = TipoMovimientoStock::all();
        $this->categorias = CategoriaProducto::select('id', 'descripcion')->orderBy('descripcion', 'asc')->get();
        $perPage = 10;
        $collection = DB::table('productos')
        ->join('categoria_producto', 'productos.categoria_producto_id', '=', 'categoria_producto.id')
        ->select('productos.clave_producto', 'productos.tipo_producto','productos.descripcion_producto', 'productos.categoria_producto_id','productos.marca_producto','productos.costo_compra','productos.precio_venta','productos.presentacion_producto','productos.id', 'stock_anterior', 'stock_actual', 'categoria_producto.descripcion as categoria')
        ->get();

        $offset = max(0, ($this->page - 1) * $perPage);
        // need one more here so the simple paginatior knows
        // if there are more pages left
        $items = $collection->slice($offset, $perPage + 1);
        $paginator = new Paginator($items, $perPage, $this->page);
        return view('livewire.Productos.productos', ['data' => $paginator]);
    }

    public function resetInput()
    {
        $this->clave_producto = null;
        $this->tipo_producto = null;
        $this->descripcion_producto = null;
        $this->categoria_producto_id = null;
        $this->marca_producto = null;
        $this->costo_compra = null;
        $this->precio_venta = null;
        $this->presentacion_producto = null;
        $this->stock_anterior = null;
        $this->stock_actual = null;
    }

    public function store()
    {
        $this->validate([
            'descripcion_producto' => 'required|min:2',
            'clave_producto' => 'required|min:2',
        ]);
        Producto::create([
            'clave_producto' => $this->clave_producto,
            'tipo_producto' => $this->tipo_producto,
            'descripcion_producto' => $this->descripcion_producto,
            'categoria_producto_id' => $this->categoria_producto_id,
            'marca_producto' => $this->marca_producto,
            'costo_compra' => $this->costo_compra,
            'precio_venta' => $this->precio_venta,
            'presentacion_producto' => $this->presentacion_producto,
            'stock_anterior' => 0,
            'stock_actual' => $this->stock_actual,
        ]);

        $this->resetInput();
    }

    public function agregarStock($id)
    {
        $this->selected_id = $id;
        $this->agregar = true;
    }

    public function actualizaStock() {
        $this->agregar = false;
        $this->Validate([
            'cantidad' => 'required|numeric',
            'tipo_movimiento_id' => 'required',
            'selected_id' => 'required|numeric',
        ]);
        $producto = Producto::find($this->selected_id);
        $producto->update([
            'stock_anterior' => $producto->stock_actual,
            'stock_actual' => $producto->stock_actual + $this->cantidad,
        ]);
        MovimientosStock::create([
            'producto_id' => $this->selected_id,
            'tipo_movimiento_stock_id' => $this->tipo_movimiento_id,
            'cantidad' => $this->cantidad,
            'user_id' => auth()->id(),
        ]);
    }

    public function edit($id)
    {
        $record = Producto::findOrFail($id);
        $this->selected_id = $id;
        $this->clave_producto = $record->clave_producto;
        $this->tipo_producto = $record->tipo_producto;
        $this->descripcion_producto = $record->descripcion_producto;
        $this->categoria_producto_id = $record->categoria_producto_id;
        $this->marca_producto = $record->marca_producto;
        $this->costo_compra = $record->costo_compra;
        $this->precio_venta = $record->precio_venta;
        $this->presentacion_producto = $record->presentacion_producto;
        $this->stock_anterior = 0;
        $this->stock_actual = $record->stock_actual;

        $this->agregar = false;
        $this->updateMode = true;
    }

    public function update()
    {
        $this->validate([
            'selected_id' => 'required|numeric'
        ]);

        if ($this->selected_id)
        {
            $record = Producto::find($this->selected_id);
            $record->update([
                'clave_producto' => $this->clave_producto,
                'tipo_producto' => $this->tipo_producto,
                'descripcion_producto' => $this->descripcion_producto,
                'categoria_producto_id' => $this->categoria_producto_id,
                'marca_producto' => $this->marca_producto,
                'costo_compra' => $this->costo_compra,
                'precio_venta' => $this->precio_venta,
                'presentacion_producto' => $this->presentacion_producto,
                'stock_anterior' => $this->stock_anterior,
                'stock_actual' => $this->stock_actual,
            ]);

            $this->resetInput();
            $this->updateMode = false;
        }
    }

    public function destroy($id)
    {
        if ($id) {
            $record = Producto::where('id', $id);
            $record->delete();
        }
    }
}
