<?php

namespace App\Http\Livewire;

use App\Models\Proveedores as ModelsProveedores;
use App\Models\Tipos_Proveedores;
use Livewire\Component;
use Livewire\WithPagination;
use Illuminate\Pagination\Paginator;
use Illuminate\Support\Facades\DB;

class Proveedores extends Component
{
    use WithPagination;

    public $tipos, $clave_interna, $nombre_negocio, $direccion, $telefono, $email, $tipo_proveedor_id, $selected_id, $rfc;
    public $updateMode = false;
    public $hacer = false;
    public $searchterm;

    public function updatingSearch()
    {
        $this->resetPage();
    }

    public function render()
    {
        $perPage = 10;
        $this->tipos = Tipos_Proveedores::all();
        $collection = DB::table('proveedores')
        ->join('tipos_proveedores', 'proveedores.tipo_proveedor_id', '=', 'tipos_proveedores.id')
        ->select('proveedores.id', 'proveedores.clave_interna', 'proveedores.nombre_negocio', 'proveedores.direccion', 'proveedores.telefono', 'proveedores.rfc', 'proveedores.email','tipos_proveedores.descripcion')
        ->get();
        $offset = max(0, ($this->page - 1) * $perPage);
        // need one more here so the simple paginatior knows
        // if there are more pages left
        $items = $collection->slice($offset, $perPage + 1);
        $paginator = new Paginator($items, $perPage, $this->page);
        return view('livewire.Proveedores.proveedores', ['data' => $paginator]);
    }

    private function resetInput()
    {
        $this->clave_interna = null;
        $this->nombre_negocio = null;
        $this->direccion = null;
        $this->telefono = null;
        $this->email = null;
        $this->tipo_proveedor_id = null;
        $this->rfc = null;
    }

    public function store()
    {
        $this->validate([
            'clave_interna' => 'required|min:2',
            'nombre_negocio' => 'required|min:2',
            'direccion' => 'required|min:2',
            'telefono' => 'required|min:2',
            'email' => 'required|min:2'
        ]);
        ModelsProveedores::create([
            'clave_interna' => $this->clave_interna,
            'nombre_negocio' => $this->nombre_negocio,
            'direccion' => $this->direccion,
            'telefono' => $this->telefono,
            'email' => $this->email,
            'tipo_proveedor_id' => $this->tipo_proveedor_id,
            'rfc' => $this->rfc
        ]);

        $this->hacer = false;
        $this->resetInput();
    }

    public function edit($id)
    {
        $record = ModelsProveedores::findOrFail($id);

        $this->selected_id = $id;
        $this->clave_interna = $record->clave_interna;
        $this->nombre_negocio = $record->nombre_negocio;
        $this->direccion = $record->direccion;
        $this->telefono = $record->telefono;
        $this->email = $record->email;
        $this->tipo_proveedor_id = $record->tipo_proveedor_id;
        $this->rfc = $record->rfc;

        $this->updateMode = true;

    }

    public function update()
    {
        $this->validate([
            'selected_id' => 'required|numeric'
        ]);

        if ($this->selected_id)
        {
            $record = ModelsProveedores::find($this->selected_id);
            $record->update([
                'clave_interna' => $this->clave_interna,
                'nombre_negocio' => $this->nombre_negocio,
                'direccion' => $this->direccion,
                'telefono' => $this->telefono,
                'email' => $this->email,
                'tipo_proveedor_id' => $this->tipo_proveedor_id,
                'rfc' => $this->rfc
            ]);

            $this->resetInput();
            $this->updateMode = false;
        }
    }

    public function search()
    {
        $this->render();
    }

    public function destroy($id)
    {
        if ($id) {
            $record = ModelsProveedores::where('id', $id);
            $record->delete();
        }
    }
}
