<?php

namespace App\Http\Livewire;

use App\Models\DetalleVentas;
use Livewire\Component;
use App\Models\Ventas;
use Barryvdh\DomPDF\Facade\Pdf;
use Illuminate\Support\Carbon;
use App\Models\MovimientosStock;
use App\Models\Clientes;
use App\Models\Productos;
use App\Models\Vendedores;
use App\Models\Abono;
use App\Models\AbonoDetalle;
use Illuminate\Support\Facades\Auth;

class Venta extends Component
{
    public $data, $productos, $clientes, $productos_ventas, $costo_compra_editado, $cantidad, $cliente_id, $tipo_venta, $costo_compra, $nombreCliente, $vendedores, $vendedor_id, $vendedor_nombre, $venta_id;
    public $inicio = false;
    public $searchTerm = '';
    public $buscarProductos = false;
    public $arrayInicial = [];
    public $create = false;
    PUBLIC $alerta = false;

    public function render()
    {
        $busqueda = $this->searchTerm
        ? Productos::where('descripcion_producto', 'LIKE', '%'.$this->searchTerm.'%')->limit(3)->get()
        : Productos::orderBy('descripcion_producto', 'desc')->limit(3)->get();
        $this->productos_ventas = $busqueda;
        $this->clientes = Clientes::all();
        $this->vendedores = Vendedores::all();
        $this->data = Ventas::with('cliente', 'usuario', 'vendedor')->orderBy('created_at', 'desc')->limit(10)->get();
        if ($this->inicio) {
            return view('livewire.Ventas.iniciar');
        } elseif ($this->buscarProductos) {
            return view('livewire.Ventas.buscar');
        } elseif ($this->create) {
            return view('livewire.Ventas.create');
        } else {
            return view('livewire.Ventas.venta');
        }

    }

    private function resetInput()
    {
        $this->cantidad = null;
    }

    private function resetInputInicial()
    {
        $this->tipo_venta = null;
        $this->cliente_id = null;
        $this->vendedor_id = null;
    }

    public function show($id)
    {
        $this->data = Ventas::with('cliente', 'usuario', 'vendedor')->where('id', '=', $id)->first();
        $this->productos = DetalleVentas::with('productos')->where('venta_id', '=', $id)->get();
        $datos = [
            'ventas' => $this->data,
            'productos' => $this->productos,
        ];
        $pdf = Pdf::loadView('livewire.Ventas.show', ['datos' => $datos]);
        return response()->streamDownload(function () use($pdf) {
            echo $pdf->stream();
        }, 'venta '.$this->data->cliente->nombre.' '.Carbon::now()->toDateString().'.pdf');
    }

    public function crear()
    {
        $this->inicio = false;
        $this->buscarProductos = true;
        $auxProveedor = Clientes::find($this->cliente_id);
        $this->nombreCliente = $auxProveedor->nombre;
        $this->render();
    }

    public function agregarProducto($id)
    {
        $prod = array();
        $this->validate([
            'cantidad' => 'required',
        ]);
        $record = Productos::findOrFail($id);

        if ($this->costo_compra_editado) {
            $costo_final = $this->costo_compra_editado;
        } else {
            $costo_final = $record->costo_compra;
        }
        $total = $this->cantidad * $costo_final;
        $prod = ([
            'id' => $record->id,
            'cantidad' => $this->cantidad,
            'costo_unitario' => $costo_final,
            'total_movimiento' => $total
        ]);
        array_push($this->arrayInicial, $prod);
        $this->resetInput();
        $this->render();
    }

    public function eliminar($index)
    {
        unset($this->arrayInicial[$index]);
        $this->render();
    }

    public function crearVenta()
    {
        $auxTotal = 0;
        foreach ($this->arrayInicial as $item) {
            $auxTotal += $item['total_movimiento'];
        }
        Ventas::create([
            'tipo_venta' => $this->tipo_venta,
            'cliente_id' => $this->cliente_id,
            'descripcion' => 'Venta por Sistema',
            'total' => $auxTotal,
            'user_id' => Auth::id(),
            'vendedor_id' => $this->vendedor_id,
            'monto_actual' => $auxTotal,
        ]);
        $this->venta_id = Ventas::latest()->first()->id;
        $this->detalleVenta($this->venta_id);
        $this->buscarProductos = false;
        $this->arrayInicial = [];
        session()->flash('message', 'Guardado con Éxito');
        $this->alerta = true;
        $this->resetInputInicial();
        $this->render();
    }

    private function detalleVenta($id)
    {
        foreach ($this->arrayInicial as $item) {
            $detalle = DetalleVentas::create([
                'venta_id' => $id,
                'producto_id' => $item['id'],
                'cantidad' => $item['cantidad'],
                'precio_unitario' => $item['costo_unitario'],
                'costo_total' => $item['total_movimiento'],
            ]);
            if ($detalle) {
                $record = Productos::find($item['id']);
                $record->update([
                    'stock_anterior' => $record->stock_actual,
                    'stock_actual' => $record->stock_actual - $item['cantidad'],
                ]);
                MovimientosStock::create([
                    'tipo_movimiento_stock_id' => 2,
                    'producto_id' => $item['id'],
                    'user_id' => Auth::id(),
                    'cantidad' => $item['cantidad'],
                    'stock_id' => 1,
                ]);
            } else {
                $resultado = [
                    'msg' => 'fallo en la inserción'
                ];
            }
        }
        $resultado = [
            'msg' => 'Inserción Exitosa'
        ];
        return $resultado;
    }
}
